action

Function action 

pub fn action(
    title: impl Into<Cow<'static, str>>,
    body: impl Into<Cow<'static, str>>,
    timeout: Option<Duration>,
    urgency: Option<Urgency>,
    actions: Vec<(String, String)>,
) -> Result<String, Error>
Send a Notification across the User Bus with a set of Actions. The selected Action, if the user choose one, is returned.

Should an error preventing sending a Notification, the dialoguer crate will be used to prompt from the terminal.