set_notifier

Function set_notifier 

pub fn set_notifier(
    function: Box<dyn Fn(&Record<'_>, Level) -> bool + Send + Sync + 'static>,
) -> Result<(), Error>
Set an optional Notifier function that is called instead of the notify() function defined here, such as to run the binary compiled by this crate in cases of SetUID, where we cannot communicate to the User Bus in this process.