pub fn init_error() -> Result<(), Error>Expand description
Initialize the NotifyLogger as the program’s Logger, but print to stderr instead of stdout. Note that this only applies to direct logging, notification call fallback still prints to stdout.